=== modified file 'EventListModel.qml'
--- EventListModel.qml	2013-03-22 01:32:02 +0000
+++ EventListModel.qml	2013-03-23 19:26:04 +0000
@@ -21,7 +21,7 @@
     }
     Component.onCompleted: {
         reload()
-        DataService.eventsNotifier.dataChanged.connect(reload)
+        DataService.eventsNotifier().dataChanged.connect(reload)
         termStartChanged.connect(reload)
     }
 }

=== modified file 'dataService.js'
--- dataService.js	2013-03-22 01:32:02 +0000
+++ dataService.js	2013-03-23 19:26:04 +0000
@@ -2,15 +2,13 @@
 
 .import QtQuick.LocalStorage 2.0 as LS
 
-var eventsNotifier = Qt.createQmlObject('import QtQuick 2.0; QtObject { signal dataChanged }', Qt.application, 'eventsNotifier')
-
 Array.prototype.append = function(x) { this.push(x) }
 
 function getEvents(termStart, termEnd, events)
 {
     var result = null
 
-    db.readTransaction(
+    db().readTransaction(
         function(tx) {
             result = tx.executeSql('\
 select * from Event \
@@ -35,7 +33,7 @@
 {
     var result = null;
 
-    db.readTransaction(
+    db().readTransaction(
         function(tx) {
             result = tx.executeSql('\
 select c.* from Attendance a, Contact c \
@@ -58,7 +56,7 @@
 {
     var result = null
 
-    db.transaction(
+    db().transaction(
         function(tx) {
             result = tx.executeSql('\
 insert into Event(title, message, startTime, endTime) \
@@ -70,14 +68,14 @@
 
     event.id = result.insertId
 
-    eventsNotifier.dataChanged()
+    eventsNotifier().dataChanged()
 
     return event
 }
 
 function removeEvent(event)
 {
-    db.transaction(
+    db().transaction(
         function(tx) {
             tx.executeSql(
                 'delete from Event where id = ?',
@@ -96,14 +94,14 @@
 
     delete event.id
 
-    eventsNotifier.dataChanged()
+    eventsNotifier().dataChanged()
 }
 
 function getContacts(contacts)
 {
     var result = null
 
-    db.readTransaction(
+    db().readTransaction(
         function(tx) {
             result = tx.executeSql('select * from Contact order by name')
         }
@@ -119,7 +117,7 @@
 
 function addAttendee(event, contact)
 {
-    db.transaction(
+    db().transaction(
         function(tx) {
             tx.executeSql(
                 'insert into Attendance(eventId, contactId) values (?, ?)',
@@ -131,7 +129,7 @@
 
 function removeAttendee(event, contact)
 {
-    db.transaction(
+    db().transaction(
         function(tx) {
             tx.executeSql(
                 'delete from Attendance where eventId = ? and contactId = ?',
@@ -145,7 +143,7 @@
 {
     var result = null
 
-    db.readTransaction(
+    db().readTransaction(
         function(tx) {
             result = tx.executeSql('select * from Place')
         }
@@ -167,7 +165,7 @@
     if (typeof place.latitude == 'undefined') place.latitude = null
     if (typeof place.longitude == 'undefined') place.longitude = null
 
-    db.transaction(
+    db().transaction(
         function(tx) {
             result = tx.executeSql(
                 'insert into Place(name, address, latitude, longitude) values(?, ?, ?, ?)',
@@ -183,7 +181,7 @@
 
 function removePlace(place)
 {
-    db.transaction(
+    db().transaction(
         function(tx) {
             tx.executeSql(
                 'delete from Place where id = ?',
@@ -201,7 +199,7 @@
 
 function addVenue(event, place)
 {
-    db.transaction(
+    db().transaction(
         function(tx) {
             tx.executeSql(
                 'insert into Venue(eventId, placeId) values(?, ?)',
@@ -213,7 +211,7 @@
 
 function removeVenue(event, place)
 {
-    db.transaction(
+    db().transaction(
         function(tx) {
             tx.executeSql(
                 'delete from Venue where eventId = ? and placeId = ?',
@@ -227,7 +225,7 @@
 {
     var result = null
 
-    db.readTransaction(
+    db().readTransaction(
         function(tx) {
             result = tx.executeSql('\
 select p.* \
@@ -329,7 +327,7 @@
 \
 '.split(';')
 
-    for (var i in schema) {
+    for (var i = 0; i < schema.length; ++i) {
         var sql = schema[i]
         if (sql != "") {
             console.log(sql)
@@ -338,5 +336,18 @@
     }
 }
 
-var db = LS.LocalStorage.openDatabaseSync("Calendar", "", "Offline Calendar", 100000)
-if (db.version == "") db.changeVersion("", "0.1", __createFirstTime)
+function eventsNotifier()
+{
+    if (!eventsNotifier.hasOwnProperty("instance"))
+        eventsNotifier.instance = Qt.createQmlObject('import QtQuick 2.0; QtObject { signal dataChanged }', Qt.application, 'DataService.eventsNotifier()')
+    return eventsNotifier.instance
+}
+
+function db()
+{
+    if (!db.hasOwnProperty("instance")) {
+        db.instance = LS.LocalStorage.openDatabaseSync("Calendar", "", "Offline Calendar", 100000)
+        if (db.instance.version == "") db.instance.changeVersion("", "0.1", __createFirstTime)
+    }
+    return db.instance
+}

=== modified file 'dataServiceTests.js'
--- dataServiceTests.js	2013-03-22 01:32:02 +0000
+++ dataServiceTests.js	2013-03-23 19:26:04 +0000
@@ -184,7 +184,7 @@
     DataService.removePlace(testPlace)
 }
 
-DataService.db.transaction(
+DataService.db().transaction(
     function (tx) {
         runTestSimple(tx)
         loadTestDataComplex(tx)

